#line 1 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
/*
* Copyright (c) 2015-2018, Intel Corporation
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  * Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*  * Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
*  * Neither the name of Intel Corporation nor the names of its contributors
*    may be used to endorse or promote products derived from this software
*    without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*/

#include "config.h"

#include "ExpressionParser.h"

#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <string>

#include "ue2common.h"
#include "hs_compile.h"


using std::string;

namespace { // anon
	
	enum ParamKey {
		PARAM_NONE,
		PARAM_MIN_OFFSET,
		PARAM_MAX_OFFSET,
		PARAM_MIN_LENGTH,
		PARAM_EDIT_DISTANCE,
		PARAM_HAMM_DISTANCE
	};
	

#line 57 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"
static const signed char _ExpressionParser_actions[] = {
		0, 1, 0, 1, 1, 1, 2, 1,
		3, 1, 4, 1, 5, 1, 6, 1,
		7, 1, 9, 1, 10, 2, 8, 0,
		0
	};
	
	static const int ExpressionParser_start = 56;
	static const int ExpressionParser_first_final = 56;
	static const int ExpressionParser_error = 0;
	
	static const int ExpressionParser_en_main = 56;
	
	
#line 116 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"

	
} // namespace

static
void initExt(hs_expr_ext *ext) {
	memset(ext, 0, sizeof(*ext));
	ext->max_offset = MAX_OFFSET;
}

bool HS_CDECL readExpression(const std::string &input, std::string &expr,
unsigned int *flags, hs_expr_ext *ext,
bool *must_be_ordered) {
	assert(flags);
	assert(ext);
	
	// Init flags and ext params.
	*flags = 0;
	initExt(ext);
	if (must_be_ordered) {
		*must_be_ordered = false;
	}
	
	// Extract expr, which is easier to do in straight C++ than with Ragel.
	if (input.empty() || input[0] != '/') {
		return false;
	}
	size_t end = input.find_last_of('/');
	if (end == string::npos || end == 0) {
		return false;
	}
	expr = input.substr(1, end - 1);
	
	// Use a Ragel scanner to handle flags and params.
	const char *p = input.c_str() + end + 1;
	const char *pe = input.c_str() + input.size();
	UNUSED const char *eof = pe;
	UNUSED const char *ts = p, *te = p;
	int cs;
	UNUSED int act;
	
	assert(p);
	assert(pe);
	
	// For storing integers as they're scanned.
	u64a num = 0;
	enum ParamKey key = PARAM_NONE;
	

#line 119 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"
	{
		cs = (int)ExpressionParser_start;
	}

#line 122 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"
{
		const signed char * _acts;
		unsigned int _nacts;
		
		_resume: {}
		if ( p == pe && p != eof )
			goto _out;
		switch ( cs ) {
			case 56:
			if ( p == eof ) {
				goto _ctr122;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 56u: {
						goto _ctr123;
					}
					case 67u: {
						goto _ctr123;
					}
					case 72u: {
						goto _ctr123;
					}
					case 76u: {
						goto _ctr123;
					}
					case 105u: {
						goto _ctr123;
					}
					case 109u: {
						goto _ctr123;
					}
					case 115u: {
						goto _ctr123;
					}
					case 123u: {
						goto _ctr124;
					}
				}
				if ( ( (*( p))) > 81u ) {
					if ( 86u <= ( (*( p))) && ( (*( p))) <= 87u ) {
						goto _ctr123;
					}
				} else if ( ( (*( p))) >= 79u ) {
					goto _ctr123;
				}
				goto _ctr2;
			}
			case 0:
			if ( p == eof ) {
				goto _ctr0;	goto _again;
			}
			else {
				goto _again;
			}
			case 1:
			if ( p == eof ) {
				goto _ctr1;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 32u: {
						goto _ctr3;
					}
					case 101u: {
						goto _ctr4;
					}
					case 104u: {
						goto _ctr5;
					}
					case 109u: {
						goto _ctr6;
					}
				}
				goto _ctr2;
			}
			case 2:
			if ( p == eof ) {
				goto _ctr7;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 32u: {
						goto _ctr8;
					}
					case 101u: {
						goto _ctr9;
					}
					case 104u: {
						goto _ctr10;
					}
					case 109u: {
						goto _ctr11;
					}
				}
				goto _ctr2;
			}
			case 3:
			if ( p == eof ) {
				goto _ctr12;	goto _again;
			}
			else {
				if ( ( (*( p))) == 100u ) {
					goto _ctr13;
				}
				goto _ctr2;
			}
			case 4:
			if ( p == eof ) {
				goto _ctr14;	goto _again;
			}
			else {
				if ( ( (*( p))) == 105u ) {
					goto _ctr15;
				}
				goto _ctr2;
			}
			case 5:
			if ( p == eof ) {
				goto _ctr16;	goto _again;
			}
			else {
				if ( ( (*( p))) == 116u ) {
					goto _ctr17;
				}
				goto _ctr2;
			}
			case 6:
			if ( p == eof ) {
				goto _ctr18;	goto _again;
			}
			else {
				if ( ( (*( p))) == 95u ) {
					goto _ctr19;
				}
				goto _ctr2;
			}
			case 7:
			if ( p == eof ) {
				goto _ctr20;	goto _again;
			}
			else {
				if ( ( (*( p))) == 100u ) {
					goto _ctr21;
				}
				goto _ctr2;
			}
			case 8:
			if ( p == eof ) {
				goto _ctr22;	goto _again;
			}
			else {
				if ( ( (*( p))) == 105u ) {
					goto _ctr23;
				}
				goto _ctr2;
			}
			case 9:
			if ( p == eof ) {
				goto _ctr24;	goto _again;
			}
			else {
				if ( ( (*( p))) == 115u ) {
					goto _ctr25;
				}
				goto _ctr2;
			}
			case 10:
			if ( p == eof ) {
				goto _ctr26;	goto _again;
			}
			else {
				if ( ( (*( p))) == 116u ) {
					goto _ctr27;
				}
				goto _ctr2;
			}
			case 11:
			if ( p == eof ) {
				goto _ctr28;	goto _again;
			}
			else {
				if ( ( (*( p))) == 97u ) {
					goto _ctr29;
				}
				goto _ctr2;
			}
			case 12:
			if ( p == eof ) {
				goto _ctr30;	goto _again;
			}
			else {
				if ( ( (*( p))) == 110u ) {
					goto _ctr31;
				}
				goto _ctr2;
			}
			case 13:
			if ( p == eof ) {
				goto _ctr32;	goto _again;
			}
			else {
				if ( ( (*( p))) == 99u ) {
					goto _ctr33;
				}
				goto _ctr2;
			}
			case 14:
			if ( p == eof ) {
				goto _ctr34;	goto _again;
			}
			else {
				if ( ( (*( p))) == 101u ) {
					goto _ctr35;
				}
				goto _ctr2;
			}
			case 15:
			if ( p == eof ) {
				goto _ctr36;	goto _again;
			}
			else {
				if ( ( (*( p))) == 61u ) {
					goto _ctr37;
				}
				goto _ctr2;
			}
			case 16:
			if ( p == eof ) {
				goto _ctr38;	goto _again;
			}
			else {
				if ( 48u <= ( (*( p))) && ( (*( p))) <= 57u ) {
					goto _ctr39;
				}
				goto _ctr2;
			}
			case 17:
			if ( p == eof ) {
				goto _ctr40;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 32u: {
						goto _ctr41;
					}
					case 44u: {
						goto _ctr42;
					}
					case 125u: {
						goto _ctr44;
					}
				}
				if ( 48u <= ( (*( p))) && ( (*( p))) <= 57u ) {
					goto _ctr43;
				}
				goto _ctr2;
			}
			case 18:
			if ( p == eof ) {
				goto _ctr45;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 32u: {
						goto _ctr41;
					}
					case 44u: {
						goto _ctr42;
					}
					case 125u: {
						goto _ctr44;
					}
				}
				goto _ctr2;
			}
			case 57:
			if ( p == eof ) {
				goto _ctr125;	goto _again;
			}
			else {
				goto _ctr2;
			}
			case 19:
			if ( p == eof ) {
				goto _ctr46;	goto _again;
			}
			else {
				if ( ( (*( p))) == 97u ) {
					goto _ctr47;
				}
				goto _ctr2;
			}
			case 20:
			if ( p == eof ) {
				goto _ctr48;	goto _again;
			}
			else {
				if ( ( (*( p))) == 109u ) {
					goto _ctr49;
				}
				goto _ctr2;
			}
			case 21:
			if ( p == eof ) {
				goto _ctr50;	goto _again;
			}
			else {
				if ( ( (*( p))) == 109u ) {
					goto _ctr51;
				}
				goto _ctr2;
			}
			case 22:
			if ( p == eof ) {
				goto _ctr52;	goto _again;
			}
			else {
				if ( ( (*( p))) == 105u ) {
					goto _ctr53;
				}
				goto _ctr2;
			}
			case 23:
			if ( p == eof ) {
				goto _ctr54;	goto _again;
			}
			else {
				if ( ( (*( p))) == 110u ) {
					goto _ctr55;
				}
				goto _ctr2;
			}
			case 24:
			if ( p == eof ) {
				goto _ctr56;	goto _again;
			}
			else {
				if ( ( (*( p))) == 103u ) {
					goto _ctr57;
				}
				goto _ctr2;
			}
			case 25:
			if ( p == eof ) {
				goto _ctr58;	goto _again;
			}
			else {
				if ( ( (*( p))) == 95u ) {
					goto _ctr59;
				}
				goto _ctr2;
			}
			case 26:
			if ( p == eof ) {
				goto _ctr60;	goto _again;
			}
			else {
				if ( ( (*( p))) == 100u ) {
					goto _ctr61;
				}
				goto _ctr2;
			}
			case 27:
			if ( p == eof ) {
				goto _ctr62;	goto _again;
			}
			else {
				if ( ( (*( p))) == 105u ) {
					goto _ctr63;
				}
				goto _ctr2;
			}
			case 28:
			if ( p == eof ) {
				goto _ctr64;	goto _again;
			}
			else {
				if ( ( (*( p))) == 115u ) {
					goto _ctr65;
				}
				goto _ctr2;
			}
			case 29:
			if ( p == eof ) {
				goto _ctr66;	goto _again;
			}
			else {
				if ( ( (*( p))) == 116u ) {
					goto _ctr67;
				}
				goto _ctr2;
			}
			case 30:
			if ( p == eof ) {
				goto _ctr68;	goto _again;
			}
			else {
				if ( ( (*( p))) == 97u ) {
					goto _ctr69;
				}
				goto _ctr2;
			}
			case 31:
			if ( p == eof ) {
				goto _ctr70;	goto _again;
			}
			else {
				if ( ( (*( p))) == 110u ) {
					goto _ctr71;
				}
				goto _ctr2;
			}
			case 32:
			if ( p == eof ) {
				goto _ctr72;	goto _again;
			}
			else {
				if ( ( (*( p))) == 99u ) {
					goto _ctr73;
				}
				goto _ctr2;
			}
			case 33:
			if ( p == eof ) {
				goto _ctr74;	goto _again;
			}
			else {
				if ( ( (*( p))) == 101u ) {
					goto _ctr75;
				}
				goto _ctr2;
			}
			case 34:
			if ( p == eof ) {
				goto _ctr76;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 97u: {
						goto _ctr77;
					}
					case 105u: {
						goto _ctr78;
					}
				}
				goto _ctr2;
			}
			case 35:
			if ( p == eof ) {
				goto _ctr79;	goto _again;
			}
			else {
				if ( ( (*( p))) == 120u ) {
					goto _ctr80;
				}
				goto _ctr2;
			}
			case 36:
			if ( p == eof ) {
				goto _ctr81;	goto _again;
			}
			else {
				if ( ( (*( p))) == 95u ) {
					goto _ctr82;
				}
				goto _ctr2;
			}
			case 37:
			if ( p == eof ) {
				goto _ctr83;	goto _again;
			}
			else {
				if ( ( (*( p))) == 111u ) {
					goto _ctr84;
				}
				goto _ctr2;
			}
			case 38:
			if ( p == eof ) {
				goto _ctr85;	goto _again;
			}
			else {
				if ( ( (*( p))) == 102u ) {
					goto _ctr86;
				}
				goto _ctr2;
			}
			case 39:
			if ( p == eof ) {
				goto _ctr87;	goto _again;
			}
			else {
				if ( ( (*( p))) == 102u ) {
					goto _ctr88;
				}
				goto _ctr2;
			}
			case 40:
			if ( p == eof ) {
				goto _ctr89;	goto _again;
			}
			else {
				if ( ( (*( p))) == 115u ) {
					goto _ctr90;
				}
				goto _ctr2;
			}
			case 41:
			if ( p == eof ) {
				goto _ctr91;	goto _again;
			}
			else {
				if ( ( (*( p))) == 101u ) {
					goto _ctr92;
				}
				goto _ctr2;
			}
			case 42:
			if ( p == eof ) {
				goto _ctr93;	goto _again;
			}
			else {
				if ( ( (*( p))) == 116u ) {
					goto _ctr94;
				}
				goto _ctr2;
			}
			case 43:
			if ( p == eof ) {
				goto _ctr95;	goto _again;
			}
			else {
				if ( ( (*( p))) == 110u ) {
					goto _ctr96;
				}
				goto _ctr2;
			}
			case 44:
			if ( p == eof ) {
				goto _ctr97;	goto _again;
			}
			else {
				if ( ( (*( p))) == 95u ) {
					goto _ctr98;
				}
				goto _ctr2;
			}
			case 45:
			if ( p == eof ) {
				goto _ctr99;	goto _again;
			}
			else {
				switch( ( (*( p))) ) {
					case 108u: {
						goto _ctr100;
					}
					case 111u: {
						goto _ctr101;
					}
				}
				goto _ctr2;
			}
			case 46:
			if ( p == eof ) {
				goto _ctr102;	goto _again;
			}
			else {
				if ( ( (*( p))) == 101u ) {
					goto _ctr103;
				}
				goto _ctr2;
			}
			case 47:
			if ( p == eof ) {
				goto _ctr104;	goto _again;
			}
			else {
				if ( ( (*( p))) == 110u ) {
					goto _ctr105;
				}
				goto _ctr2;
			}
			case 48:
			if ( p == eof ) {
				goto _ctr106;	goto _again;
			}
			else {
				if ( ( (*( p))) == 103u ) {
					goto _ctr107;
				}
				goto _ctr2;
			}
			case 49:
			if ( p == eof ) {
				goto _ctr108;	goto _again;
			}
			else {
				if ( ( (*( p))) == 116u ) {
					goto _ctr109;
				}
				goto _ctr2;
			}
			case 50:
			if ( p == eof ) {
				goto _ctr110;	goto _again;
			}
			else {
				if ( ( (*( p))) == 104u ) {
					goto _ctr111;
				}
				goto _ctr2;
			}
			case 51:
			if ( p == eof ) {
				goto _ctr112;	goto _again;
			}
			else {
				if ( ( (*( p))) == 102u ) {
					goto _ctr113;
				}
				goto _ctr2;
			}
			case 52:
			if ( p == eof ) {
				goto _ctr114;	goto _again;
			}
			else {
				if ( ( (*( p))) == 102u ) {
					goto _ctr115;
				}
				goto _ctr2;
			}
			case 53:
			if ( p == eof ) {
				goto _ctr116;	goto _again;
			}
			else {
				if ( ( (*( p))) == 115u ) {
					goto _ctr117;
				}
				goto _ctr2;
			}
			case 54:
			if ( p == eof ) {
				goto _ctr118;	goto _again;
			}
			else {
				if ( ( (*( p))) == 101u ) {
					goto _ctr119;
				}
				goto _ctr2;
			}
			case 55:
			if ( p == eof ) {
				goto _ctr120;	goto _again;
			}
			else {
				if ( ( (*( p))) == 116u ) {
					goto _ctr121;
				}
				goto _ctr2;
			}
		}
		
		_ctr0: cs = 0; goto _again;
		_ctr2: cs = 0; goto f0;
		_ctr124: cs = 1; goto _again;
		_ctr1: cs = 1; goto f0;
		_ctr42: cs = 1; goto f4;
		_ctr8: cs = 2; goto _again;
		_ctr7: cs = 2; goto f0;
		_ctr3: cs = 2; goto f1;
		_ctr9: cs = 3; goto _again;
		_ctr12: cs = 3; goto f0;
		_ctr4: cs = 3; goto f1;
		_ctr13: cs = 4; goto _again;
		_ctr14: cs = 4; goto f0;
		_ctr15: cs = 5; goto _again;
		_ctr16: cs = 5; goto f0;
		_ctr17: cs = 6; goto _again;
		_ctr18: cs = 6; goto f0;
		_ctr19: cs = 7; goto _again;
		_ctr20: cs = 7; goto f0;
		_ctr21: cs = 8; goto _again;
		_ctr22: cs = 8; goto f0;
		_ctr23: cs = 9; goto _again;
		_ctr24: cs = 9; goto f0;
		_ctr25: cs = 10; goto _again;
		_ctr26: cs = 10; goto f0;
		_ctr27: cs = 11; goto _again;
		_ctr28: cs = 11; goto f0;
		_ctr29: cs = 12; goto _again;
		_ctr30: cs = 12; goto f0;
		_ctr31: cs = 13; goto _again;
		_ctr32: cs = 13; goto f0;
		_ctr33: cs = 14; goto _again;
		_ctr34: cs = 14; goto f0;
		_ctr36: cs = 15; goto f0;
		_ctr35: cs = 15; goto f2;
		_ctr75: cs = 15; goto f6;
		_ctr94: cs = 15; goto f7;
		_ctr111: cs = 15; goto f8;
		_ctr121: cs = 15; goto f9;
		_ctr37: cs = 16; goto _again;
		_ctr38: cs = 16; goto f0;
		_ctr40: cs = 17; goto f0;
		_ctr39: cs = 17; goto f3;
		_ctr43: cs = 17; goto f5;
		_ctr41: cs = 18; goto _again;
		_ctr45: cs = 18; goto f0;
		_ctr10: cs = 19; goto _again;
		_ctr46: cs = 19; goto f0;
		_ctr5: cs = 19; goto f1;
		_ctr47: cs = 20; goto _again;
		_ctr48: cs = 20; goto f0;
		_ctr49: cs = 21; goto _again;
		_ctr50: cs = 21; goto f0;
		_ctr51: cs = 22; goto _again;
		_ctr52: cs = 22; goto f0;
		_ctr53: cs = 23; goto _again;
		_ctr54: cs = 23; goto f0;
		_ctr55: cs = 24; goto _again;
		_ctr56: cs = 24; goto f0;
		_ctr57: cs = 25; goto _again;
		_ctr58: cs = 25; goto f0;
		_ctr59: cs = 26; goto _again;
		_ctr60: cs = 26; goto f0;
		_ctr61: cs = 27; goto _again;
		_ctr62: cs = 27; goto f0;
		_ctr63: cs = 28; goto _again;
		_ctr64: cs = 28; goto f0;
		_ctr65: cs = 29; goto _again;
		_ctr66: cs = 29; goto f0;
		_ctr67: cs = 30; goto _again;
		_ctr68: cs = 30; goto f0;
		_ctr69: cs = 31; goto _again;
		_ctr70: cs = 31; goto f0;
		_ctr71: cs = 32; goto _again;
		_ctr72: cs = 32; goto f0;
		_ctr73: cs = 33; goto _again;
		_ctr74: cs = 33; goto f0;
		_ctr11: cs = 34; goto _again;
		_ctr76: cs = 34; goto f0;
		_ctr6: cs = 34; goto f1;
		_ctr77: cs = 35; goto _again;
		_ctr79: cs = 35; goto f0;
		_ctr80: cs = 36; goto _again;
		_ctr81: cs = 36; goto f0;
		_ctr82: cs = 37; goto _again;
		_ctr83: cs = 37; goto f0;
		_ctr84: cs = 38; goto _again;
		_ctr85: cs = 38; goto f0;
		_ctr86: cs = 39; goto _again;
		_ctr87: cs = 39; goto f0;
		_ctr88: cs = 40; goto _again;
		_ctr89: cs = 40; goto f0;
		_ctr90: cs = 41; goto _again;
		_ctr91: cs = 41; goto f0;
		_ctr92: cs = 42; goto _again;
		_ctr93: cs = 42; goto f0;
		_ctr78: cs = 43; goto _again;
		_ctr95: cs = 43; goto f0;
		_ctr96: cs = 44; goto _again;
		_ctr97: cs = 44; goto f0;
		_ctr98: cs = 45; goto _again;
		_ctr99: cs = 45; goto f0;
		_ctr100: cs = 46; goto _again;
		_ctr102: cs = 46; goto f0;
		_ctr103: cs = 47; goto _again;
		_ctr104: cs = 47; goto f0;
		_ctr105: cs = 48; goto _again;
		_ctr106: cs = 48; goto f0;
		_ctr107: cs = 49; goto _again;
		_ctr108: cs = 49; goto f0;
		_ctr109: cs = 50; goto _again;
		_ctr110: cs = 50; goto f0;
		_ctr101: cs = 51; goto _again;
		_ctr112: cs = 51; goto f0;
		_ctr113: cs = 52; goto _again;
		_ctr114: cs = 52; goto f0;
		_ctr115: cs = 53; goto _again;
		_ctr116: cs = 53; goto f0;
		_ctr117: cs = 54; goto _again;
		_ctr118: cs = 54; goto f0;
		_ctr119: cs = 55; goto _again;
		_ctr120: cs = 55; goto f0;
		_ctr122: cs = 56; goto _again;
		_ctr123: cs = 56; goto f10;
		_ctr125: cs = 57; goto _again;
		_ctr44: cs = 57; goto f4;
		
		f5: _acts = ( _ExpressionParser_actions + (1)); goto execFuncs;
		f10: _acts = ( _ExpressionParser_actions + (3)); goto execFuncs;
		f4: _acts = ( _ExpressionParser_actions + (5)); goto execFuncs;
		f9: _acts = ( _ExpressionParser_actions + (7)); goto execFuncs;
		f7: _acts = ( _ExpressionParser_actions + (9)); goto execFuncs;
		f8: _acts = ( _ExpressionParser_actions + (11)); goto execFuncs;
		f2: _acts = ( _ExpressionParser_actions + (13)); goto execFuncs;
		f6: _acts = ( _ExpressionParser_actions + (15)); goto execFuncs;
		f1: _acts = ( _ExpressionParser_actions + (17)); goto execFuncs;
		f0: _acts = ( _ExpressionParser_actions + (19)); goto execFuncs;
		f3: _acts = ( _ExpressionParser_actions + (21)); goto execFuncs;
		
		execFuncs:
		_nacts = (unsigned int)(*( _acts));
		_acts += 1;
		while ( _nacts > 0 ) {
			switch ( (*( _acts)) ) {
				case 0: {
						{
#line 60 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						
						num = (num * 10) + ((( (*( p)))) - '0');
					}
					
#line 938 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 1: {
						{
#line 64 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						
						switch ((( (*( p))))) {
							case 'i': *flags |= HS_FLAG_CASELESS; break;
							case 's': *flags |= HS_FLAG_DOTALL; break;
							case 'm': *flags |= HS_FLAG_MULTILINE; break;
							case 'H': *flags |= HS_FLAG_SINGLEMATCH; break;
							case 'O':
							if (must_be_ordered) {
								*must_be_ordered = true;
							}
							break;
							case 'V': *flags |= HS_FLAG_ALLOWEMPTY; break;
							case 'W': *flags |= HS_FLAG_UCP; break;
							case '8': *flags |= HS_FLAG_UTF8; break;
							case 'P': *flags |= HS_FLAG_PREFILTER; break;
							case 'L': *flags |= HS_FLAG_SOM_LEFTMOST; break;
							case 'C': *flags |= HS_FLAG_COMBINATION; break;
							case 'Q': *flags |= HS_FLAG_QUIET; break;
							default: {p += 1; goto _out; }
						}
					}
					
#line 966 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 2: {
						{
#line 86 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						
						switch (key) {
							case PARAM_MIN_OFFSET:
							ext->flags |= HS_EXT_FLAG_MIN_OFFSET;
							ext->min_offset = num;
							break;
							case PARAM_MAX_OFFSET:
							ext->flags |= HS_EXT_FLAG_MAX_OFFSET;
							ext->max_offset = num;
							break;
							case PARAM_MIN_LENGTH:
							ext->flags |= HS_EXT_FLAG_MIN_LENGTH;
							ext->min_length = num;
							break;
							case PARAM_EDIT_DISTANCE:
							ext->flags |= HS_EXT_FLAG_EDIT_DISTANCE;
							ext->edit_distance = num;
							break;
							case PARAM_HAMM_DISTANCE:
							ext->flags |= HS_EXT_FLAG_HAMMING_DISTANCE;
							ext->hamming_distance = num;
							break;
							case PARAM_NONE:
							default:
							// No key specified, syntax invalid.
							return false;
						}
					}
					
#line 1001 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 3: {
						{
#line 166 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						key = PARAM_MIN_OFFSET; }
					
#line 1009 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 4: {
						{
#line 167 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						key = PARAM_MAX_OFFSET; }
					
#line 1017 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 5: {
						{
#line 168 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						key = PARAM_MIN_LENGTH; }
					
#line 1025 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 6: {
						{
#line 169 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						key = PARAM_EDIT_DISTANCE; }
					
#line 1033 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 7: {
						{
#line 170 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						key = PARAM_HAMM_DISTANCE; }
					
#line 1041 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 8: {
						{
#line 172 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						num = 0;}
					
#line 1049 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 9: {
						{
#line 173 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						key = PARAM_NONE; }
					
#line 1057 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
				case 10: {
						{
#line 178 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"
						return false; }
					
#line 1065 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/build/util//ExpressionParser.cpp"

					break; 
				}
			}
			_acts += 1;
			_nacts -= 1;
		}
		
		goto _again;
		
		_again: {}
		if ( p == eof ) {
			if ( cs >= 56 )
				goto _out;
		}
		else {
			if ( cs != 0 ) {
				p += 1;
				goto _resume;
			}
		}
		_out: {}
	}
	
#line 183 "/home/abuild/rpmbuild/BUILD/vectorscan-vectorscan-5.4.11/util/ExpressionParser.rl"

	
	DEBUG_PRINTF("expr='%s', flags=%u\n", expr.c_str(), *flags);
	
	return (cs != ExpressionParser_error) && (p == pe);
}
